@@ -59,13 +59,11 @@ sub parse_todo
 
 sub expand_version
 {
-  my($op, $ver, $cperl) = @_;
+  my($op, $ver) = @_;
   my($r, $v, $s) = parse_version($ver);
   $r == 5 or die "only Perl revision 5 is supported\n";
   my $bcdver = sprintf "0x%d%03d%03d", $r, $v, $s;
-  my $ret = "(PERL_BCDVERSION $op $bcdver)";
-  $ret = "defined(USE_CPERL) && " . $ret if $cperl;
-  return $ret;
+  return "(PERL_BCDVERSION $op $bcdver)";
 }
 
 sub parse_partspec
@@ -77,12 +75,6 @@ sub parse_partspec
   my(%data, %options);
   local *F;
 
-  my $Test_Harness_VERSION = 3;
-  if ($] < 5.008001) { # cannot do no_plan?
-    require Test::Harness;
-    $Test_Harness_VERSION = $Test::Harness::VERSION;
-  }
-
   open F, $file or die "$file: $!\n";
   while (<F>) {
     /[ \t]+$/ and warn "$file:$.: warning: trailing whitespace\n";
@@ -97,17 +89,6 @@ sub parse_partspec
         my $opt = $2;
         $options{$section} = eval "{ $opt }";
         $@ and die "$file:$.: invalid options ($opt) in section $section: $@\n";
-        if ($opt =~ /plan\s+=>\s+['"]?no_plan['"]?/) {
-          $options{$section}{plan} = "no_plan";
-          if ($Test_Harness_VERSION < 2) {
-            if ($opt =~ /fallback\s+=>\s+(\d+)/) {
-              $options{$section}{plan} = $1;
-            } else {
-              $options{$section}{plan} =
-                'skip => "Test::Harness 2 or fallback required"';
-            }
-          }
-        }
       }
       next;
     }
@@ -186,7 +167,7 @@ sub parse_partspec
 
   for $section (qw( implementation xsubs xsinit xsmisc xshead xsboot )) {
     if (exists $data{$section}) {
-      $data{$section} =~ s/\{\s*(CPERL\s*&&\s*)?version\s*(<|>|==|!=|>=|<=)\s*([\d._]+)\s*\}/expand_version($2, $3, $1)/gei;
+      $data{$section} =~ s/\{\s*version\s*(<|>|==|!=|>=|<=)\s*([\d._]+)\s*\}/expand_version($1, $2)/gei;
     }
   }
 
@@ -323,46 +304,27 @@ sub parse_embed
       }
       else {
         my @e = split /\s*\|\s*/, $line;
-        if ( @e >= 3 ) {
-          my ($flags, $ret, $name, @args) = @e;
-          next unless $flags =~ /A/; # Skip non-public entries
-
-          # Skip entries marked as deprecated or unstable,
-          next if $flags =~ /[DM]/;
+        if( @e >= 3 ) {
+          my($flags, $ret, $name, @args) = @e;
+          next if $flags =~ /[DM]/; # Skip entries marked as deprecated or unstable
           if ($name =~ /^[^\W\d]\w*$/) {
             for (@args) {
               $_ = [trim_arg($_)];
             }
             ($ret) = trim_arg($ret);
-            my $cond = $pps[-1];
-            if ($cond and $cond->{cur} and
-                $cond->{cur} =~ /\bdefined\(USE_CPERL\)/ and
-                $^V !~ /c$/) {
-              print "skip cperl-specific $name $flags\n" unless $SILENT;
-            }
-            elsif ($cond and @{$cond->{pre}} and
-                   !defined $cond->{cur} and
-                   @{$cond->{pre}}[-1] =~ /\bdefined\(USE_CPERL\)/ and
-                   $^V =~ /c$/) {
-              print "skip perl5-specific $name $flags\n" unless $SILENT;
-            }
-            else {
-              push @func, {
-                name  => $name,
-                flags => { map { $_, 1 } $flags =~ /./g },
-                ret   => $ret,
-                args  => \@args,
-                cond  => ppcond(\@pps),
-              }
+            push @func, {
+              name  => $name,
+              flags => { map { $_, 1 } $flags =~ /./g },
+              ret   => $ret,
+              args  => \@args,
+              cond  => ppcond(\@pps),
             };
           }
-          # like
-          #    PL_parser->linestr
-          # which documents a struct entry rather than a function
-          elsif ($name =~ /^PL_parser->(\w*)$/) {
-            ;
+          elsif ($name =~ /^[^\W\d]\w*-E<gt>[^\W\d]\w*$/) {
+            # silenty ignore entries of the form
+            #    PL_parser-E<gt>linestr
+            # which documents a struct entry rather than a function
           }
-          # but warn about non names
           else {
             warn "mysterious name [$name] in $file, line $.\n";
           }
@@ -418,7 +380,7 @@ sub parse_version
   if ($ver =~ /^(\d+)\.(\d+)\.(\d+)$/) {
     return ($1, $2, $3);
   }
-  elsif ($ver !~ /^\d+\.\d{3}(?:_\d{2})?$/) {
+  elsif ($ver !~ /^\d+\.[\d_]+$/) {
     die "cannot parse version '$ver'\n";
   }
 
